@rem Export au format html de l'ensemble des paramètres quotidiens, avec les noms de variables originaux en anglais
WlkTransformer.exe -to html -export resume123 -id frou -d1 201402 -Tunit C -Uunit U -Vunit kmph -Dunit degre -Runit mm -Punit hpa -confirm oui -heureMinMax oui -locale en -ftp non

@rem Exemples:
@rem Envoi par ftp de la dernière prévision
@rem WlkTransformer.exe -to html -export lastForecast -locale fr -ftp oui

@rem Export au format csv des données mesurées sur la période du 1 au 10/02 toutes les heures
@rem WlkTransformer.exe -to csv -export wdata -d1 201402010000 -d2 201402102359 -Tunit C -Uunit U -Vunit kmph -Dunit secteur -Runit mm -Punit hpa -confirm non -heureMinMax oui -intervalWdata 60

@rem +--------------------+
@rem | WlkTransformer 1.1 |
@rem +--------------------+
@rem   Utilitaire de recodage des fichiers 'aaaa-mm.wlk' du logiciel (c)Weatherlink de Davis Instrument,
@rem   permettant la creation de fichiers 'texte' personnalises dans les formats CSV, HTML, SQL.
@rem   Il est possible de definir :
@rem     - la periode
@rem     - les parametres meteos
@rem     - l'unite des parametres meteos
@rem     - le format de la ligne de texte
@rem     - l'intervalle d'export entre 2 parametres mesures
@rem     - le libelle des noms de parametres (CSV, HTML) ou des noms de champs SQL (anglais ou francais)
@rem     - un identifiant de station
@rem   Par ailleurs, l'envoi par ftp des fichiers produits vers un serveur distant peut etre defini.

@rem   Pour plus de details sur la configuration du traitement, se reporter au fichier 'WlkTransformer.conf'.
@rem -----------------------------------------------------------------------------------------------------------------
@rem   Syntaxe :        WlkTransformer -to ... -export ... [-d1 ...] [-d2 ...] [-id ...] ...
@rem -----------------------------------------------------------------------------------------------------------------
@rem Arguments principaux :
@rem    -to : format en sortie parmi 'csv', 'html', 'sql'
@rem        --> 'csv': les donnees sont exportees vers un fichier au format CSV (pour tableur comme Excel, Libre Office)
@rem        --> 'html': les donnees sont exportees vers un fichier au format HTML (tableau lisible par tout navigateur)
@rem        --> 'sql': les donnees sont exportees vers un fichier au format SQL (pour alimenter une base de donnees)
@rem    -export : type de fichier a creer, parmi 'wdata', 'resume1', 'resume2', 'resume3', 'all', 'resume123', 'lastForecast'
@rem        --> 'wdata': les parametres 'temps reel' directement mesures par la station
@rem        --> 'resume1': les parametres quotidiens principaux releves sur la journee du fichier WLK (tempe., pluie, vent, ...)
@rem        --> 'resume2': les parametres quotidiens secondaires releves sur la journee du fichier WLK (rayon., DJU, ET, ...)
@rem        --> 'resume3': les parametres quotidiens Tn, Tx, RR recalcules selon la norme OMM (Tn-1818, Tx-0606, RR-0606)
@rem                       ou sur la journee UTC (Tn-0024, Tx-0024, RR-0024)
@rem        --> 'all': export de l'ensemble des fichiers 'wdata' + 'resume1' + 'resume2' + 'resume3'
@rem        --> 'resume123': les 3 resumes 'resume1', 'resume2', 'resume3' sont exportes dans le MEME fichier
@rem        --> 'lastForecast': le dernier message de prevision disponible en clair
@rem    -d1 : date de debut au format AAAAMM ou AAAAMMJJ ou AAAAMMJJHHmm (= 1er du mois en cours a 00:00 si omis)
@rem    -d2 : date de fin au format AAAAMM ou AAAAMMJJ ou AAAAMMJJHHmm (= fin du mois de d1 a 23:59 si omis)
@rem    -id : identifiant de station = numero ou nom (facultatif, ajoute un champ lors d'un export csv ou sql, ou un titre en html)
@rem
@rem Arguments de mise en forme de l'export :
@rem    -intervalWdata : intervalle d'export des parametres mesures en minutes parmi 1,2,5,10,15,30,60,120,180,240,360,720,1440
@rem    -heureMinMax : 'oui' pour afficher l'heure des parametres extremes quotidiens
@rem                   'non' pour ne pas afficher l'heure des parametres extremes quotidiens
@rem    -locale : 'fr' pour exporter les textes en francais (nom court des parametres, titre de colonne, message de prevision)
@rem              'en' pour exporter les textes en anglais
@rem    -Tunit : choix de l'unite de temperature parmi 'C', 'F', 'K', 'C10', 'F10', 'K10'
@rem    -Uunit : choix de l'unite d'humidite parmi 'U', 'U10'
@rem    -Vunit : choix de l'unite de force du vent parmi 'kmph', 'mps', 'Kt', 'Mph', 'Bft', kmph10', 'mps10', 'Kt10', 'Mph10'
@rem    -Dunit : choix de l'unite de direction du vent parmi 'secteur', 'degre', 'indice'
@rem    -Runit : choix de l'unite de mesure de pluie parmi 'mm', 'inch', 'mm10', 'inch1000'
@rem    -Punit : choix de l'unite de pression parmi 'hpa', 'mmHg', 'inHg', 'hpa10', 'mmHg10', 'inHg1000'
@rem             !! Plus d'informations sur les unites dans le fichier de configuration 'WlkTransformer.conf' !!
@rem
@rem Autres arguments facultatifs :
@rem    -ftp : 'oui' pour envoyer les resultats vers un serveur distant. ('non' pour bloquer l'envoi)
@rem           !! Initialisation des parametres ftp dans le fichier de configuration 'WlkTransformer.conf' !!
@rem    -conf : nom du fichier de configuration a utiliser (lu dans le repertoire ./conf ou donner le nom complet)
@rem    -confirm : 'oui' pour afficher une demande de confirmation avant traitement
@rem               'non' pour supprimer la demande de confirmation avant traitement (mode automatique)
@rem    -licence : licence d'utilisation du programme
@rem    -v, -version : version du programme
@rem    -h : this help
@rem
@rem Exemple: export au format SQL des donnees quotidennes de 02/2014 (permet d'alimenter une base de donnees)
@rem WlkTransformer -to sql -export resume1 -d1 201402
@rem
@rem Generateur de ligne de commande: http://meteofrouzins.fr/wlktrans_commencer.php
@rem Documentation complete: http://wlktransformer.meteofrouzins.fr
@rem Contact: info@meteofrouzins.fr
